@@ -46,6 +46,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "bind", 200 },
 	{ "bpf", 280 },
 	{ "break", __PNR_break },
+	{ "breakpoint", __PNR_breakpoint },
 	{ "brk", 214 },
 	{ "cachectl", __PNR_cachectl },
 	{ "cacheflush", __PNR_cacheflush },
@@ -322,6 +323,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "set_robust_list", 99 },
 	{ "set_thread_area", __PNR_set_thread_area },
 	{ "set_tid_address", 96 },
+	{ "set_tls", __PNR_set_tls },
 	{ "setdomainname", 162 },
 	{ "setfsgid", 152 },
 	{ "setfsgid32", __PNR_setfsgid32 },
@@ -417,6 +419,8 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "unlinkat", 35 },
 	{ "unshare", 97 },
 	{ "uselib", __PNR_uselib },
+	{ "usr26", __PNR_usr26 },
+	{ "usr32", __PNR_usr32 },
 	{ "ustat", __PNR_ustat },
 	{ "utime", __PNR_utime },
 	{ "utimensat", 88 },
