@@ -27,6 +27,7 @@
 #include "arch-arm.h"
 
 #define __NR_OABI_SYSCALL_BASE	0x900000
+#define __ARM_NR_BASE		0x0f0000
 
 /* NOTE: we currently only support the ARM EABI, more info at the URL below:
  *       -> http://wiki.embeddedarm.com/wiki/EABI_vs_OABI */
@@ -49,7 +50,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "add_key", (__NR_SYSCALL_BASE + 309) },
 	{ "adjtimex", (__NR_SYSCALL_BASE + 124) },
 	{ "afs_syscall", __PNR_afs_syscall },
-	{ "alarm", (__NR_SYSCALL_BASE + 27) },
+	{ "alarm", __PNR_alarm },
 	{ "arm_fadvise64_64", (__NR_SYSCALL_BASE + 270) },
 	{ "arm_sync_file_range", (__NR_SYSCALL_BASE + 341) },
 	{ "arch_prctl", __PNR_arch_prctl },
@@ -57,9 +58,10 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "bind", (__NR_SYSCALL_BASE + 282) },
 	{ "bpf", (__NR_SYSCALL_BASE + 386) },
 	{ "break", __PNR_break },
+	{ "breakpoint", (__NR_SYSCALL_BASE + (__ARM_NR_BASE + 1)) },
 	{ "brk", (__NR_SYSCALL_BASE + 45) },
 	{ "cachectl", __PNR_cachectl },
-	{ "cacheflush", __PNR_cacheflush },
+	{ "cacheflush", (__NR_SYSCALL_BASE + (__ARM_NR_BASE + 2)) },
 	{ "capget", (__NR_SYSCALL_BASE + 184) },
 	{ "capset", (__NR_SYSCALL_BASE + 185) },
 	{ "chdir", (__NR_SYSCALL_BASE + 12) },
@@ -156,7 +158,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "getresgid32", (__NR_SYSCALL_BASE + 211) },
 	{ "getresuid", (__NR_SYSCALL_BASE + 165) },
 	{ "getresuid32", (__NR_SYSCALL_BASE + 209) },
-	{ "getrlimit", (__NR_SYSCALL_BASE + 76) },
+	{ "getrlimit", __PNR_getrlimit },
 	{ "getrusage", (__NR_SYSCALL_BASE + 77) },
 	{ "getsid", (__NR_SYSCALL_BASE + 147) },
 	{ "getsockname", (__NR_SYSCALL_BASE + 286) },
@@ -183,7 +185,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "iopl", __PNR_iopl },
 	{ "ioprio_get", (__NR_SYSCALL_BASE + 315) },
 	{ "ioprio_set", (__NR_SYSCALL_BASE + 314) },
-	{ "ipc", (__NR_SYSCALL_BASE + 117) },
+	{ "ipc", __PNR_ipc },
 	{ "kcmp", (__NR_SYSCALL_BASE + 378) },
 	{ "kexec_file_load", __PNR_kexec_file_load },
 	{ "kexec_load", (__NR_SYSCALL_BASE + 347) },
@@ -215,7 +217,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "mknodat", (__NR_SYSCALL_BASE + 324) },
 	{ "mlock", (__NR_SYSCALL_BASE + 150) },
 	{ "mlockall", (__NR_SYSCALL_BASE + 152) },
-	{ "mmap", (__NR_SYSCALL_BASE + 90) },
+	{ "mmap", __PNR_mmap },
 	{ "mmap2", (__NR_SYSCALL_BASE + 192) },
 	{ "modify_ldt", __PNR_modify_ldt },
 	{ "mount", (__NR_SYSCALL_BASE + 21) },
@@ -279,7 +281,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "quotactl", (__NR_SYSCALL_BASE + 131) },
 	{ "read", (__NR_SYSCALL_BASE +  3) },
 	{ "readahead", (__NR_SYSCALL_BASE + 225) },
-	{ "readdir", (__NR_SYSCALL_BASE + 89) },
+	{ "readdir", __PNR_readdir },
 	{ "readlink", (__NR_SYSCALL_BASE + 85) },
 	{ "readlinkat", (__NR_SYSCALL_BASE + 332) },
 	{ "readv", (__NR_SYSCALL_BASE + 145) },
@@ -318,7 +320,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "sched_yield", (__NR_SYSCALL_BASE + 158) },
 	{ "seccomp", (__NR_SYSCALL_BASE + 383) },
 	{ "security", __PNR_security },
-	{ "select", (__NR_SYSCALL_BASE + 82) },
+	{ "select", __PNR_select },
 	{ "semctl", (__NR_SYSCALL_BASE + 300) },
 	{ "semget", (__NR_SYSCALL_BASE + 299) },
 	{ "semop", (__NR_SYSCALL_BASE + 298) },
@@ -333,6 +335,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "set_robust_list", (__NR_SYSCALL_BASE + 338) },
 	{ "set_thread_area", __PNR_set_thread_area },
 	{ "set_tid_address", (__NR_SYSCALL_BASE + 256) },
+	{ "set_tls", (__NR_SYSCALL_BASE + (__ARM_NR_BASE + 5)) },
 	{ "setdomainname", (__NR_SYSCALL_BASE + 121) },
 	{ "setfsgid", (__NR_SYSCALL_BASE + 139) },
 	{ "setfsgid32", (__NR_SYSCALL_BASE + 216) },
@@ -378,7 +381,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "sigreturn", (__NR_SYSCALL_BASE + 119) },
 	{ "sigsuspend", (__NR_SYSCALL_BASE + 72) },
 	{ "socket", (__NR_SYSCALL_BASE + 281) },
-	{ "socketcall", (__NR_SYSCALL_BASE + 102) },
+	{ "socketcall", __PNR_socketcall },
 	{ "socketpair", (__NR_SYSCALL_BASE + 288) },
 	{ "splice", (__NR_SYSCALL_BASE + 340) },
 	{ "ssetmask", __PNR_ssetmask },
@@ -386,7 +389,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "stat64", (__NR_SYSCALL_BASE + 195) },
 	{ "statfs", (__NR_SYSCALL_BASE + 99) },
 	{ "statfs64", (__NR_SYSCALL_BASE + 266) },
-	{ "stime", (__NR_SYSCALL_BASE + 25) },
+	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "swapoff", (__NR_SYSCALL_BASE + 115) },
 	{ "swapon", (__NR_SYSCALL_BASE + 87) },
@@ -396,14 +399,14 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "sync_file_range", __PNR_sync_file_range },
 	{ "sync_file_range2", (__NR_SYSCALL_BASE + 341) },
 	{ "syncfs", (__NR_SYSCALL_BASE + 373) },
-	{ "syscall", (__NR_SYSCALL_BASE + 113) },
+	{ "syscall", __PNR_syscall },
 	{ "sysfs", (__NR_SYSCALL_BASE + 135) },
 	{ "sysinfo", (__NR_SYSCALL_BASE + 116) },
 	{ "syslog", (__NR_SYSCALL_BASE + 103) },
 	{ "sysmips", __PNR_sysmips },
 	{ "tee", (__NR_SYSCALL_BASE + 342) },
 	{ "tgkill", (__NR_SYSCALL_BASE + 268) },
-	{ "time", (__NR_SYSCALL_BASE + 13) },
+	{ "time", __PNR_time },
 	{ "timer_create", (__NR_SYSCALL_BASE + 257) },
 	{ "timer_delete", (__NR_SYSCALL_BASE + 261) },
 	{ "timer_getoverrun", (__NR_SYSCALL_BASE + 260) },
@@ -421,15 +424,17 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "ugetrlimit", (__NR_SYSCALL_BASE + 191) },
 	{ "ulimit", __PNR_ulimit },
 	{ "umask", (__NR_SYSCALL_BASE + 60) },
-	{ "umount", (__NR_SYSCALL_BASE + 22) },
+	{ "umount", __PNR_umount },
 	{ "umount2", (__NR_SYSCALL_BASE + 52) },
 	{ "uname", (__NR_SYSCALL_BASE + 122) },
 	{ "unlink", (__NR_SYSCALL_BASE + 10) },
 	{ "unlinkat", (__NR_SYSCALL_BASE + 328) },
 	{ "unshare", (__NR_SYSCALL_BASE + 337) },
 	{ "uselib", (__NR_SYSCALL_BASE + 86) },
+	{ "usr26", (__NR_SYSCALL_BASE + (__ARM_NR_BASE + 3)) },
+	{ "usr32", (__NR_SYSCALL_BASE + (__ARM_NR_BASE + 4)) },
 	{ "ustat", (__NR_SYSCALL_BASE + 62) },
-	{ "utime", (__NR_SYSCALL_BASE + 30) },
+	{ "utime", __PNR_utime },
 	{ "utimensat", (__NR_SYSCALL_BASE + 348) },
 	{ "utimes", (__NR_SYSCALL_BASE + 269) },
 	{ "vfork", (__NR_SYSCALL_BASE + 190) },
