@@ -50,6 +50,7 @@ const struct arch_syscall_def mips_syscall_table[] = { \
 	{ "bind", (__NR_SYSCALL_BASE + 169) },
 	{ "bpf", (__NR_SYSCALL_BASE + 355) },
 	{ "break", __NR_SYSCALL_BASE + 17 },
+	{ "breakpoint", __PNR_breakpoint },
 	{ "brk", (__NR_SYSCALL_BASE + 45) },
 	{ "cachectl", (__NR_SYSCALL_BASE + 148) },
 	{ "cacheflush", (__NR_SYSCALL_BASE + 147) },
@@ -326,6 +327,7 @@ const struct arch_syscall_def mips_syscall_table[] = { \
 	{ "set_robust_list", (__NR_SYSCALL_BASE + 309) },
 	{ "set_thread_area", (__NR_SYSCALL_BASE + 283) },
 	{ "set_tid_address", (__NR_SYSCALL_BASE + 252) },
+	{ "set_tls", __PNR_set_tls },
 	{ "setdomainname", (__NR_SYSCALL_BASE + 121) },
 	{ "setfsgid", (__NR_SYSCALL_BASE + 139) },
 	{ "setfsgid32", __PNR_setfsgid32 },
@@ -421,6 +423,8 @@ const struct arch_syscall_def mips_syscall_table[] = { \
 	{ "unlinkat", (__NR_SYSCALL_BASE + 294) },
 	{ "unshare", (__NR_SYSCALL_BASE + 303) },
 	{ "uselib", (__NR_SYSCALL_BASE + 86) },
+	{ "usr26", __PNR_usr26 },
+	{ "usr32", __PNR_usr32 },
 	{ "ustat", (__NR_SYSCALL_BASE + 62) },
 	{ "utime", (__NR_SYSCALL_BASE + 30) },
 	{ "utimensat", (__NR_SYSCALL_BASE + 316) },
