@@ -50,6 +50,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "bind", (__NR_SYSCALL_BASE + 48) },
 	{ "bpf", (__NR_SYSCALL_BASE + 319) },
 	{ "break", __PNR_break },
+	{ "breakpoint", __PNR_breakpoint },
 	{ "brk", (__NR_SYSCALL_BASE + 12) },
 	{ "cachectl", (__NR_SYSCALL_BASE + 198) },
 	{ "cacheflush", (__NR_SYSCALL_BASE + 197) },
@@ -326,6 +327,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "set_robust_list", (__NR_SYSCALL_BASE + 272) },
 	{ "set_thread_area", (__NR_SYSCALL_BASE + 246) },
 	{ "set_tid_address", (__NR_SYSCALL_BASE + 213) },
+	{ "set_tls", __PNR_set_tls },
 	{ "setdomainname", (__NR_SYSCALL_BASE + 166) },
 	{ "setfsgid", (__NR_SYSCALL_BASE + 121) },
 	{ "setfsgid32", __PNR_setfsgid32 },
@@ -421,6 +423,8 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "unlinkat", (__NR_SYSCALL_BASE + 257) },
 	{ "unshare", (__NR_SYSCALL_BASE + 266) },
 	{ "uselib", __PNR_uselib },
+	{ "usr26", __PNR_usr26 },
+	{ "usr32", __PNR_usr32 },
 	{ "ustat", (__NR_SYSCALL_BASE + 133) },
 	{ "utime", (__NR_SYSCALL_BASE + 130) },
 	{ "utimensat", (__NR_SYSCALL_BASE + 279) },
