@@ -29,11 +29,11 @@
 
 #define X32_SYSCALL_BIT			0x40000000
 
-#define x32_arg_count_max		6
-
 extern const struct arch_def arch_def_x32;
 
 int x32_syscall_resolve_name(const char *name);
 const char *x32_syscall_resolve_num(int num);
 
+const char *x32_syscall_iterate_name(unsigned int spot);
+
 #endif
