@@ -28,13 +28,13 @@
 #include "db.h"
 #include "system.h"
 
-#define x86_arg_count_max		6
-
 extern const struct arch_def arch_def_x86;
 
 int x86_syscall_resolve_name(const char *name);
 const char *x86_syscall_resolve_num(int num);
 
+const char *x86_syscall_iterate_name(unsigned int spot);
+
 int x86_syscall_rewrite(const struct arch_def *arch, bool strict, int *syscall);
 
 int x86_filter_rewrite(const struct arch_def *arch, bool strict,
