@@ -46,6 +46,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "bind", 49 },
 	{ "bpf", 321 },
 	{ "break", __PNR_break },
+	{ "breakpoint", __PNR_breakpoint },
 	{ "brk", 12 },
 	{ "cachectl", __PNR_cachectl },
 	{ "cacheflush", __PNR_cacheflush },
@@ -322,6 +323,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "set_robust_list", 273 },
 	{ "set_thread_area", 205 },
 	{ "set_tid_address", 218 },
+	{ "set_tls", __PNR_set_tls },
 	{ "setdomainname", 171 },
 	{ "setfsgid", 123 },
 	{ "setfsgid32", __PNR_setfsgid32 },
@@ -417,6 +419,8 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "unlinkat", 263 },
 	{ "unshare", 272 },
 	{ "uselib", 134 },
+	{ "usr26", __PNR_usr26 },
+	{ "usr32", __PNR_usr32 },
 	{ "ustat", 136 },
 	{ "utime", 132 },
 	{ "utimensat", 280 },
