@@ -19,6 +19,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses>.
  */
 
+#include <errno.h>
 #include <unistd.h>
 
 #include <seccomp.h>
@@ -29,7 +30,7 @@ int main(int argc, char *argv[])
 {
 	int rc;
 	struct util_options opts;
-	scmp_filter_ctx ctx;
+	scmp_filter_ctx ctx = NULL;
 
 	rc = util_getopt(argc, argv, &opts);
 	if (rc < 0)
@@ -37,8 +38,7 @@ int main(int argc, char *argv[])
 
 	ctx = seccomp_init(SCMP_ACT_KILL);
 	if (ctx == NULL)
-		goto out;
-
+		return ENOMEM;
 
 	rc = seccomp_rule_add_exact(ctx, SCMP_ACT_ALLOW, SCMP_SYS(read), 0);
 	if (rc != 0)
