@@ -78,6 +78,27 @@ int main(int argc, char *argv[])
 		case SCMP_ARCH_ARM:
 			printf("arm\n");
 			break;
+		case SCMP_ARCH_AARCH64:
+			printf("aarch64\n");
+			break;
+		case SCMP_ARCH_MIPS:
+			printf("mips\n");
+			break;
+		case SCMP_ARCH_MIPSEL:
+			printf("mipsel\n");
+			break;
+		case SCMP_ARCH_MIPS64:
+			printf("mips64\n");
+			break;
+		case SCMP_ARCH_MIPSEL64:
+			printf("mipsel64\n");
+			break;
+		case SCMP_ARCH_MIPS64N32:
+			printf("mips64n32\n");
+			break;
+		case SCMP_ARCH_MIPSEL64N32:
+			printf("mipsel64n32\n");
+			break;
 		default:
 			printf("unknown\n");
 		}
